@@ -21,30 +21,30 @@ from botocore.response import StreamingBody
 from .literals import SortOrderTypeType
 from .paginator import ListSecretsPaginator
 from .type_defs import (
-    CancelRotateSecretResponseTypeDef,
-    CreateSecretResponseTypeDef,
-    DeleteResourcePolicyResponseTypeDef,
-    DeleteSecretResponseTypeDef,
-    DescribeSecretResponseTypeDef,
+    CancelRotateSecretResponseResponseTypeDef,
+    CreateSecretResponseResponseTypeDef,
+    DeleteResourcePolicyResponseResponseTypeDef,
+    DeleteSecretResponseResponseTypeDef,
+    DescribeSecretResponseResponseTypeDef,
     FilterTypeDef,
-    GetRandomPasswordResponseTypeDef,
-    GetResourcePolicyResponseTypeDef,
-    GetSecretValueResponseTypeDef,
-    ListSecretsResponseTypeDef,
-    ListSecretVersionIdsResponseTypeDef,
-    PutResourcePolicyResponseTypeDef,
-    PutSecretValueResponseTypeDef,
-    RemoveRegionsFromReplicationResponseTypeDef,
+    GetRandomPasswordResponseResponseTypeDef,
+    GetResourcePolicyResponseResponseTypeDef,
+    GetSecretValueResponseResponseTypeDef,
+    ListSecretsResponseResponseTypeDef,
+    ListSecretVersionIdsResponseResponseTypeDef,
+    PutResourcePolicyResponseResponseTypeDef,
+    PutSecretValueResponseResponseTypeDef,
+    RemoveRegionsFromReplicationResponseResponseTypeDef,
     ReplicaRegionTypeTypeDef,
-    ReplicateSecretToRegionsResponseTypeDef,
-    RestoreSecretResponseTypeDef,
-    RotateSecretResponseTypeDef,
+    ReplicateSecretToRegionsResponseResponseTypeDef,
+    RestoreSecretResponseResponseTypeDef,
+    RotateSecretResponseResponseTypeDef,
     RotationRulesTypeTypeDef,
-    StopReplicationToReplicaResponseTypeDef,
+    StopReplicationToReplicaResponseResponseTypeDef,
     TagTypeDef,
-    UpdateSecretResponseTypeDef,
-    UpdateSecretVersionStageResponseTypeDef,
-    ValidateResourcePolicyResponseTypeDef,
+    UpdateSecretResponseResponseTypeDef,
+    UpdateSecretVersionStageResponseResponseTypeDef,
+    ValidateResourcePolicyResponseResponseTypeDef,
 )
 
 if sys.version_info >= (3, 8):
@@ -82,7 +82,7 @@ class Exceptions:
 
 class SecretsManagerClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/secretsmanager.html#SecretsManager.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html)
     """
 
@@ -91,13 +91,18 @@ class SecretsManagerClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/secretsmanager.html#SecretsManager.Client.can_paginate)
+        Check if an operation can be paginated.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#can_paginate)
         """
 
-    def cancel_rotate_secret(self, *, SecretId: str) -> CancelRotateSecretResponseTypeDef:
+    def cancel_rotate_secret(self, *, SecretId: str) -> CancelRotateSecretResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/secretsmanager.html#SecretsManager.Client.cancel_rotate_secret)
+        Disables automatic scheduled rotation and cancels the rotation of a secret if
+        currently in progress.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Client.cancel_rotate_secret)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#cancel_rotate_secret)
         """
 
@@ -111,17 +116,23 @@ class SecretsManagerClient:
         SecretBinary: Union[bytes, IO[bytes], StreamingBody] = None,
         SecretString: str = None,
         Tags: List["TagTypeDef"] = None,
-        AddReplicaRegions: List[ReplicaRegionTypeTypeDef] = None,
+        AddReplicaRegions: List["ReplicaRegionTypeTypeDef"] = None,
         ForceOverwriteReplicaSecret: bool = None
-    ) -> CreateSecretResponseTypeDef:
+    ) -> CreateSecretResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/secretsmanager.html#SecretsManager.Client.create_secret)
+        Creates a new secret.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Client.create_secret)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#create_secret)
         """
 
-    def delete_resource_policy(self, *, SecretId: str) -> DeleteResourcePolicyResponseTypeDef:
+    def delete_resource_policy(
+        self, *, SecretId: str
+    ) -> DeleteResourcePolicyResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/secretsmanager.html#SecretsManager.Client.delete_resource_policy)
+        Deletes the resource-based permission policy attached to the secret.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Client.delete_resource_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#delete_resource_policy)
         """
 
@@ -131,15 +142,19 @@ class SecretsManagerClient:
         SecretId: str,
         RecoveryWindowInDays: int = None,
         ForceDeleteWithoutRecovery: bool = None
-    ) -> DeleteSecretResponseTypeDef:
+    ) -> DeleteSecretResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/secretsmanager.html#SecretsManager.Client.delete_secret)
+        Deletes an entire secret and all of the versions.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Client.delete_secret)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#delete_secret)
         """
 
-    def describe_secret(self, *, SecretId: str) -> DescribeSecretResponseTypeDef:
+    def describe_secret(self, *, SecretId: str) -> DescribeSecretResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/secretsmanager.html#SecretsManager.Client.describe_secret)
+        Retrieves the details of a secret.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Client.describe_secret)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#describe_secret)
         """
 
@@ -151,7 +166,9 @@ class SecretsManagerClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/secretsmanager.html#SecretsManager.Client.generate_presigned_url)
+        Generate a presigned url given a client, its method, and arguments.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#generate_presigned_url)
         """
 
@@ -166,23 +183,31 @@ class SecretsManagerClient:
         ExcludeLowercase: bool = None,
         IncludeSpace: bool = None,
         RequireEachIncludedType: bool = None
-    ) -> GetRandomPasswordResponseTypeDef:
+    ) -> GetRandomPasswordResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/secretsmanager.html#SecretsManager.Client.get_random_password)
+        Generates a random password of the specified complexity.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Client.get_random_password)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#get_random_password)
         """
 
-    def get_resource_policy(self, *, SecretId: str) -> GetResourcePolicyResponseTypeDef:
+    def get_resource_policy(self, *, SecretId: str) -> GetResourcePolicyResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/secretsmanager.html#SecretsManager.Client.get_resource_policy)
+        Retrieves the JSON text of the resource-based policy document attached to the
+        specified secret.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Client.get_resource_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#get_resource_policy)
         """
 
     def get_secret_value(
         self, *, SecretId: str, VersionId: str = None, VersionStage: str = None
-    ) -> GetSecretValueResponseTypeDef:
+    ) -> GetSecretValueResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/secretsmanager.html#SecretsManager.Client.get_secret_value)
+        Retrieves the contents of the encrypted fields `SecretString` or `SecretBinary`
+        from the specified version of a secret, whichever contains content.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Client.get_secret_value)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#get_secret_value)
         """
 
@@ -193,9 +218,11 @@ class SecretsManagerClient:
         MaxResults: int = None,
         NextToken: str = None,
         IncludeDeprecated: bool = None
-    ) -> ListSecretVersionIdsResponseTypeDef:
+    ) -> ListSecretVersionIdsResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/secretsmanager.html#SecretsManager.Client.list_secret_version_ids)
+        Lists all of the versions attached to the specified secret.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Client.list_secret_version_ids)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#list_secret_version_ids)
         """
 
@@ -204,19 +231,24 @@ class SecretsManagerClient:
         *,
         MaxResults: int = None,
         NextToken: str = None,
-        Filters: List[FilterTypeDef] = None,
+        Filters: List["FilterTypeDef"] = None,
         SortOrder: SortOrderTypeType = None
-    ) -> ListSecretsResponseTypeDef:
+    ) -> ListSecretsResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/secretsmanager.html#SecretsManager.Client.list_secrets)
+        Lists all of the secrets that are stored by Secrets Manager in the AWS account.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Client.list_secrets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#list_secrets)
         """
 
     def put_resource_policy(
         self, *, SecretId: str, ResourcePolicy: str, BlockPublicPolicy: bool = None
-    ) -> PutResourcePolicyResponseTypeDef:
+    ) -> PutResourcePolicyResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/secretsmanager.html#SecretsManager.Client.put_resource_policy)
+        Attaches the contents of the specified resource-based permission policy to a
+        secret.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Client.put_resource_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#put_resource_policy)
         """
 
@@ -228,17 +260,21 @@ class SecretsManagerClient:
         SecretBinary: Union[bytes, IO[bytes], StreamingBody] = None,
         SecretString: str = None,
         VersionStages: List[str] = None
-    ) -> PutSecretValueResponseTypeDef:
+    ) -> PutSecretValueResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/secretsmanager.html#SecretsManager.Client.put_secret_value)
+        Stores a new encrypted secret value in the specified secret.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Client.put_secret_value)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#put_secret_value)
         """
 
     def remove_regions_from_replication(
         self, *, SecretId: str, RemoveReplicaRegions: List[str]
-    ) -> RemoveRegionsFromReplicationResponseTypeDef:
+    ) -> RemoveRegionsFromReplicationResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/secretsmanager.html#SecretsManager.Client.remove_regions_from_replication)
+        Remove regions from replication.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Client.remove_regions_from_replication)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#remove_regions_from_replication)
         """
 
@@ -246,17 +282,23 @@ class SecretsManagerClient:
         self,
         *,
         SecretId: str,
-        AddReplicaRegions: List[ReplicaRegionTypeTypeDef],
+        AddReplicaRegions: List["ReplicaRegionTypeTypeDef"],
         ForceOverwriteReplicaSecret: bool = None
-    ) -> ReplicateSecretToRegionsResponseTypeDef:
+    ) -> ReplicateSecretToRegionsResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/secretsmanager.html#SecretsManager.Client.replicate_secret_to_regions)
+        Converts an existing secret to a multi-Region secret and begins replication the
+        secret to a list of new regions.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Client.replicate_secret_to_regions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#replicate_secret_to_regions)
         """
 
-    def restore_secret(self, *, SecretId: str) -> RestoreSecretResponseTypeDef:
+    def restore_secret(self, *, SecretId: str) -> RestoreSecretResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/secretsmanager.html#SecretsManager.Client.restore_secret)
+        Cancels the scheduled deletion of a secret by removing the `DeletedDate` time
+        stamp.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Client.restore_secret)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#restore_secret)
         """
 
@@ -267,29 +309,39 @@ class SecretsManagerClient:
         ClientRequestToken: str = None,
         RotationLambdaARN: str = None,
         RotationRules: "RotationRulesTypeTypeDef" = None
-    ) -> RotateSecretResponseTypeDef:
+    ) -> RotateSecretResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/secretsmanager.html#SecretsManager.Client.rotate_secret)
+        Configures and starts the asynchronous process of rotating this secret.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Client.rotate_secret)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#rotate_secret)
         """
 
     def stop_replication_to_replica(
         self, *, SecretId: str
-    ) -> StopReplicationToReplicaResponseTypeDef:
+    ) -> StopReplicationToReplicaResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/secretsmanager.html#SecretsManager.Client.stop_replication_to_replica)
+        Removes the secret from replication and promotes the secret to a regional secret
+        in the replica Region.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Client.stop_replication_to_replica)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#stop_replication_to_replica)
         """
 
     def tag_resource(self, *, SecretId: str, Tags: List["TagTypeDef"]) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/secretsmanager.html#SecretsManager.Client.tag_resource)
+        Attaches one or more tags, each consisting of a key name and a value, to the
+        specified secret.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#tag_resource)
         """
 
     def untag_resource(self, *, SecretId: str, TagKeys: List[str]) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/secretsmanager.html#SecretsManager.Client.untag_resource)
+        Removes one or more tags from the specified secret.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#untag_resource)
         """
 
@@ -302,9 +354,11 @@ class SecretsManagerClient:
         KmsKeyId: str = None,
         SecretBinary: Union[bytes, IO[bytes], StreamingBody] = None,
         SecretString: str = None
-    ) -> UpdateSecretResponseTypeDef:
+    ) -> UpdateSecretResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/secretsmanager.html#SecretsManager.Client.update_secret)
+        Modifies many of the details of the specified secret.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Client.update_secret)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#update_secret)
         """
 
@@ -315,21 +369,27 @@ class SecretsManagerClient:
         VersionStage: str,
         RemoveFromVersionId: str = None,
         MoveToVersionId: str = None
-    ) -> UpdateSecretVersionStageResponseTypeDef:
+    ) -> UpdateSecretVersionStageResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/secretsmanager.html#SecretsManager.Client.update_secret_version_stage)
+        Modifies the staging labels attached to a version of a secret.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Client.update_secret_version_stage)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#update_secret_version_stage)
         """
 
     def validate_resource_policy(
         self, *, ResourcePolicy: str, SecretId: str = None
-    ) -> ValidateResourcePolicyResponseTypeDef:
+    ) -> ValidateResourcePolicyResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/secretsmanager.html#SecretsManager.Client.validate_resource_policy)
+        Validates that the resource policy does not grant a wide range of IAM principals
+        access to your secret.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Client.validate_resource_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#validate_resource_policy)
         """
 
     def get_paginator(self, operation_name: Literal["list_secrets"]) -> ListSecretsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/paginators.html#listsecretspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/paginators.html#listsecretspaginator)
         """
